Try to fix some of the build problems, it still bumms out on:
[obnox/wireshark/wip.git] / summary.h
index 7f03594033e6cfb65e752fc107514050b6fc35c6..da1c4f3aa57b8031c7055d278d102c0f5a03beba 100644 (file)
--- a/summary.h
+++ b/summary.h
@@ -1,13 +1,12 @@
 /* summary.h
  * Definitions for capture file summary data
  *
- * $Id: summary.h,v 1.7 2002/02/08 10:07:34 guy Exp $
+ * $Id$
  *
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
 #ifndef __SUMMARY_H__
 #define __SUMMARY_H__
 
+#ifdef HAVE_LIBPCAP
+#include "capture.h"
+#endif
+
+typedef struct iface_options_tag {
+    char       *name;
+    char       *descr;
+    char       *cfilter;
+    guint64    drops;          /* number of packet drops */
+    gboolean   drops_known;    /* TRUE if number of packet drops is known */
+    gboolean   has_snap;       /* TRUE if maximum capture packet length is known */
+    int                snap;           /* Maximum captured packet length */
+    int                linktype;               /* wiretap encapsulation type */
+} iface_options;
+
 typedef struct _summary_tally {
-    guint32    bytes;          /* total bytes */
+    guint64    bytes;          /* total bytes */
     double     start_time;     /* seconds, with msec resolution */
     double     stop_time;      /* seconds, with msec resolution */
     double     elapsed_time;   /* seconds, with msec resolution,
                                   includes time before first packet
                                   and after last packet */
-    int                filtered_count; /* number of filtered packets */
     int                marked_count;   /* number of marked packets */
+    guint64    marked_bytes;   /* total bytes in the marked packets */
+    double     marked_start;   /* time in seconds, with msec resolution */
+    double     marked_stop;    /* time in seconds, with msec resolution */
+    int                ignored_count;  /* number of ignored packets */
     int                packet_count;   /* total number of packets in trace */
+    int                filtered_count; /* number of filtered packets */
+    guint64    filtered_bytes; /* total bytes in the filtered packets */
+    double     filtered_start; /* time in seconds, with msec resolution */
+    double     filtered_stop;  /* time in seconds, with msec resolution */
     const char *filename;
-    long       file_length;    /* file length in bytes */
+    gint64     file_length;    /* file length in bytes */
+    int                file_type;      /* wiretap file type */
     int                encap_type;     /* wiretap encapsulation type */
     gboolean   has_snap;       /* TRUE if maximum capture packet length is known */
     int                snap;           /* Maximum captured packet length */
     gboolean    drops_known;   /* TRUE if number of packet drops is known */
-    guint32     drops;         /* number of packet drops */
-    const char *iface;         /* interface name */
+    guint64     drops;         /* number of packet drops */
     const char *dfilter;       /* display filter */
-    const char *cfilter;       /* capture filter */
+    gboolean    is_tempfile;
+    /* capture related, use summary_fill_in_capture() to get values */
+    GArray     *ifaces;
+    gboolean   legacy;
 } summary_tally;
 
-void summary_fill_in(summary_tally *st);
+extern void
+summary_fill_in(capture_file *cf, summary_tally *st);
+
+#ifdef HAVE_LIBPCAP
+extern void
+summary_fill_in_capture(capture_options *capture_opts, summary_tally *st);
+#endif
 
 #endif /* summary.h */